Request

#[non_exhaustive]
pub enum Request { Destroy, GetXdgToplevelDrag { id: New<XdgToplevelDragV1>, data_source: WlDataSource, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the xdg_toplevel_drag_manager_v1 object

Destroy this xdg_toplevel_drag_manager_v1 object. Other objects, including xdg_toplevel_drag_v1 objects created by this factory, are not affected by this request.

This is a destructor, once received this object cannot be used any longer.



GetXdgToplevelDrag

get an xdg_toplevel_drag for a wl_data_source

Create an xdg_toplevel_drag for a drag and drop operation that is going to be started with data_source.

This request can only be made on sources used in drag-and-drop, so it must be performed before wl_data_device.start_drag. Attempting to use the source other than for drag-and-drop such as in wl_data_device.set_selection will raise an invalid_source error.

Destroying data_source while a toplevel is attached to the xdg_toplevel_drag is undefined.

Fields

data_source: WlDataSource

Implementations

Source

impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message